/// <reference types="react" />
type ProcessType = 'ellipsis' | 'shadow';
type ProcessTypeArr = ['ellipsis', 'shadow'];
type EllipsisOptionType = {
    ellipsisLineClamp?: number;
    /**
     * 是否使用JS逻辑计算文字开始折叠时显示的文案，可以传字号大小
     * 注意：
     * 1、启用此功能是为了兼容部分浏览器不支持display: -webkit-box,属性的使用（或出现异常）
     * 2、计算出来的文案可能不够完美，可以通过extraOccupiedW调整计算的误差
     * 3、这时只支持传string类型内容
     * 4、此时textEndSlot、buttonBeforeSlot所额外占用的宽度，都需要通过extraOccupiedW告知组件
     */
    isJsComputed?: boolean;
    fontSize?: number;
    fontClassName?: string;
    /**
     * 字体容器相关样式（当字体样式比较丰富时，代替掉fontSize属性），仅用于JS计算
     * 注意：
     * 1、字号大小将覆盖fontSize属性
     * 2、仅JS_COMPUTED_VALID_CSS_PROPERTIES中的CSS属性有效
     */
    fontStyle?: React.CSSProperties;
    /**
     * 紧跟文字内容尾部的额外内容，可以是icon等任意内容，例如超链接icon，点击跳转到外部网站
     * 文案溢出时显示在...后面，不溢出时在文字尾部
     * 注意：启用isJsComputed时，textEndSlot所占的宽需要通过extraOccupiedW告知才能精确计算
     */
    textEndSlot?: any;
    extraOccupiedW?: number;
    buttonBeforeSlot?: string | JSX.Element | JSX.Element[] | null;
};
type ShadowOptionType = {
    shadowInitBoxShowH?: number;
    isShadowLayer?: boolean;
    shadowClassName?: string;
    shadowStyle?: React.CSSProperties;
};
type OptionType = {
    type?: ProcessType;
    /** >>>>>>ellipsis配置 */
    ellipsisOption?: EllipsisOptionType;
    /** >>>>>>shadow配置 */
    shadowOption?: ShadowOptionType;
    buttonClassName?: string;
    buttonStyle?: React.CSSProperties;
    isClickOriginalEvent?: boolean;
    isDefaultFold?: boolean;
    unfoldButtonText?: string | JSX.Element | JSX.Element[];
    foldButtonText?: string | JSX.Element | JSX.Element[];
    isShowAllContent?: boolean;
    isMustButton?: boolean;
    isMustNoButton?: boolean;
    lineHeight?: number;
    isRenderShowAllDOM?: boolean;
};
interface TextProcessProps {
    text: string;
    className?: string;
    style?: React.CSSProperties;
    onClick?: (() => void) | null;
    getIsFold?: ((v: boolean) => void) | null;
    option?: OptionType;
}
export { ProcessType, ProcessTypeArr, EllipsisOptionType, ShadowOptionType, OptionType, TextProcessProps, };
